@@ -1,5 +1,6 @@
 """ Binary packaging and compression library for PQM-800 transient data """
-__version__ = "0.2.0"
+__version__ = "0.3"
 
 from .pak_lib import pack
 from .pak_lib import unpack
+from .pak_lib import unpack_file
